PyJAGS: The Python Interface to JAGS
====================================

Documentation
-------------

.. toctree::
 :maxdepth: 1

 getting_started
 reference

JAGS Documentation
------------------
* `JAGS manual and examples <http://sourceforge.net/projects/mcmc-jags/files/>`_

Similar projects
----------------
* `PyStan <https://pystan.readthedocs.org/>`_
* `PyMC   <https://pymc-devs.github.io/pymc/>`_
* `PyMC3  <https://pymc-devs.github.io/pymc3/>`_

Indices and tables
------------------

* :ref:`genindex`
* :ref:`search`

